@@ -15,7 +15,7 @@ import asyncio
 import json
 import logging
 from collections.abc import Callable
-from typing import TYPE_CHECKING, Any, Literal
+from typing import TYPE_CHECKING, Any
 
 from awscrt import mqtt
 from awscrt.exceptions import AwsCrtError
@@ -25,7 +25,7 @@ from ..events import EventEmitter
 from ..exceptions import MqttNotConnectedError
 from ..models import Device, DeviceFeature, DeviceStatus, EnergyUsageResponse
 from ..topic_builder import MqttTopicBuilder
-from ..unit_system import set_unit_system
+from ..unit_system import UnitSystemType, set_unit_system
 from .utils import redact_topic, topic_matches_pattern
 
 if TYPE_CHECKING:
@@ -55,7 +55,7 @@ class MqttSubscriptionManager:
         event_emitter: EventEmitter,
         schedule_coroutine: Callable[[Any], None],
         device_info_cache: MqttDeviceInfoCache | None = None,
-        unit_system: Literal["metric", "imperial"] | None = None,
+        unit_system: UnitSystemType = None,
     ):
         """
         Initialize subscription manager.
@@ -67,14 +67,15 @@ class MqttSubscriptionManager:
             schedule_coroutine: Function to schedule async tasks
             device_info_cache: Optional MqttDeviceInfoCache for caching device
                 features
-            unit_system: Preferred unit system ("metric", "imperial", or None)
+            unit_system: Preferred unit system ("metric", "us_customary",
+                or None)
         """
         self._connection = connection
         self._client_id = client_id
         self._event_emitter = event_emitter
         self._schedule_coroutine = schedule_coroutine
         self._device_info_cache = device_info_cache
-        self._unit_system: Literal["metric", "imperial"] | None = unit_system
+        self._unit_system: UnitSystemType = unit_system
 
         # Track subscriptions and handlers
         self._subscriptions: dict[str, mqtt.QoS] = {}
